@@ -14,6 +14,7 @@ sub import {
         if ($_ eq 'is_deeply') {
             no warnings 'redefine';
             *{"${pkg}::is_deeply"} = \&difflet_is_deeply;
+            *Test::More::is_deeply = \&difflet_is_deeply;
         }
     }
     *{"${pkg}::difflet_is_deeply"} = \&difflet_is_deeply;
@@ -24,7 +25,7 @@ sub difflet_is_deeply {
 
     my $builder = Test::More->builder;
     local $Test::Builder::Level = $Test::Builder::Level + 1;
-    if (-t *STDOUT) {
+    if (-t *STDOUT || $ENV{HARNESS_ACTIVE}) {
         if (_eq_deeply($got, $expected)) {
             $builder->ok(1, $msg);
         } else {
